<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | wkymlmguser Plugin 1.2                                                    |
// +---------------------------------------------------------------------------+
// | install_defaults.php                                                      |
// |                                                                           |
// | Initial Installation Defaults used when loading the online configuration  |
// | records. These settings are only used during the initial installation     |
// | and not referenced any more once the plugin is installed.                 |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2008-2012 by the following authors:                         |
// |                                                                           |
// | Authors: hiroron  - hiroron AT hiroron DOT com                            |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

/**
* Install data and defaults for the wkymlmguser plugin configuration
*
* @package wkymlmguser
*/

if (strpos(strtolower($_SERVER['PHP_SELF']), 'install_defaults.php') !== false) {
    die('This file can not be used on its own!');
}

/**
 * wkymlmguser default settings
 *
 * Initial Installation Defaults used when loading the online configuration
 * records. These settings are only used during the initial installation
 * and not referenced any more once the plugin is installed
 *
 */
global $_WMMA_DEFAULT;
$_WMMA_DEFAULT = array();

/**
 * this lets you select which functions are available for registered users only
 */
$_WMMA_DEFAULT['wkymlmguserloginrequired'] = 0;

/**
 * Set to 1 to hide the "wkymlmguser" entry from the top menu:
 */
$_WMMA_DEFAULT['hidewkymlmgusermenu']    = 0;


// メルマガ送信の個別の送信成功状況の表示有無
//    表示あり=true / 表示無し=false
$_WMMA_DEFAULT['sending_report_detail_success'] = false;

// メルマガ送信の個別の送信失敗状況の表示有無
//    表示あり=true / 表示無し=false
$_WMMA_DEFAULT['sending_report_detail_failure'] = true;

// メルマガユーザの一括登録の個別の成功状況の表示有無
//    表示あり=true / 表示無し=false
$_WMMA_DEFAULT['verbose_import_disp_success'] = false;

// メルマガユーザの一括登録の個別の失敗状況の表示有無
//    表示あり=true / 表示無し=false
$_WMMA_DEFAULT['verbose_import_disp_failure'] = false;

// メルマガユーザの一括登録の個別の成功状況をログ(error.log)へ出力
//    出力する=true / 出力しない=false
$_WMMA_DEFAULT['verbose_import_log_success'] = false;

// メルマガユーザの一括登録の個別の失敗状況をログ(error.log)へ出力
//    出力する=true / 出力しない=false
$_WMMA_DEFAULT['verbose_import_log_failure'] = true;



/**
* Initialize wkymlmguser plugin configuration
*
* Creates the database entries for the configuation if they don't already
* exist. Initial values will be taken from $_WMMA_CONF if available (e.g. from
* an old config.php), uses $_WMMA_DEFAULT otherwise.
*
* @return   boolean     true: success; false: an error occurred
*
*/
function plugin_initconfig_wkymlmguser()
{
    global $_WMMA_CONF, $_WMMA_DEFAULT;

    if (is_array($_WMMA_CONF) && (count($_WMMA_CONF) > 1)) {
        $_WMMA_DEFAULT = array_merge($_WMMA_DEFAULT, $_WMMA_CONF);
    }

    $c = config::get_instance();
    if (!$c->group_exists('wkymlmguser')) {

        $c->add('sg_main', NULL, 'subgroup', 0, 0, NULL, 0, true, 'wkymlmguser', 0);
        $c->add('tab_main', NULL, 'tab', 0, 0, NULL, 0, true, 'wkymlmguser', 0);
        $c->add('fs_main', NULL, 'fieldset', 0, 0, NULL, 0, true, 'wkymlmguser', 0);
        $c->add('wkymlmguserloginrequired', $_WMMA_DEFAULT['wkymlmguserloginrequired'],
                'select', 0, 0, 0, 10, true, 'wkymlmguser', 0);
        $c->add('hidewkymlmgusermenu', $_WMMA_DEFAULT['hidewkymlmgusermenu'],
                'select', 0, 0, 0, 20, true, 'wkymlmguser', 0);
        $c->add('sending_report_detail_success', $_WMMA_DEFAULT['sending_report_detail_success'],
                'select', 0, 0, 1, 30, true, 'wkymlmguser', 0);
        $c->add('sending_report_detail_failure', $_WMMA_DEFAULT['sending_report_detail_failure'],
                'select', 0, 0, 1, 40, true, 'wkymlmguser', 0);
        $c->add('verbose_import_disp_success', $_WMMA_DEFAULT['verbose_import_disp_success'],
                'select', 0, 0, 1, 50, true, 'wkymlmguser', 0);
        $c->add('verbose_import_disp_failure', $_WMMA_DEFAULT['verbose_import_disp_failure'],
                'select', 0, 0, 1, 60, true, 'wkymlmguser', 0);
        $c->add('verbose_import_log_success', $_WMMA_DEFAULT['verbose_import_log_success'],
                'select', 0, 0, 1, 70, true, 'wkymlmguser', 0);
        $c->add('verbose_import_log_failure', $_WMMA_DEFAULT['verbose_import_log_failure'],
                'select', 0, 0, 1, 80, true, 'wkymlmguser', 0);

    }

    return true;
}

?>
